@@ -1,3 +1,5 @@
+unless ENV['DEBIAN_DISABLE_RUBYGEMS_INTEGRATION']
+
 class << Gem
 
   alias :upstream_default_dir :default_dir
@@ -12,7 +14,16 @@ class << Gem
 
   alias :upstream_default_path :default_path
   def default_path
-    upstream_default_path + [File.join('/usr/share/rubygems-integration', Gem::ConfigMap[:ruby_version]), '/usr/share/rubygems-integration/all']
+    extra_path = nil
+    if RbConfig::CONFIG['ruby_version'] == '2.1.0'
+      extra_path = File.join('/usr/share/rubygems-integration', '2.1')
+    end
+
+    upstream_default_path + [
+      File.join('/usr/share/rubygems-integration', Gem::ConfigMap[:ruby_version]),
+      extra_path,
+      '/usr/share/rubygems-integration/all'
+    ].compact
   end
 
 end
@@ -27,3 +38,5 @@ if RUBY_VERSION >= '2.0' then
 
   end
 end
+
+end
